@@ -43,7 +43,6 @@ SUPPORTED_AUDIO_FORMAT = {
 }
 ERROR_IN_SEND_THREAD = 11000
 
-
 class SpeechConfig:
     """Setup speech arguments"""
 
@@ -333,11 +332,14 @@ class Recognizer():
         self.__canceled_event = EventSignal()
         self.session_id = None
 
-        # stats for monitoring session
-        self.reconnecting = False
-        self.monitor_session = monitor_session
+        # stats for monitoring session (deprecated)
+        self.monitor_session = False # Deprecated in v0.2.6
         self.connection_id = str(uuid.uuid4())
         self.seconds_received = 0
+        if monitor_session == True:
+            svc_logger.warn("Session monitoring was deprecated in v0.2.6")
+
+        self.reconnecting = False
 
         # Speech Recognition itn options
         self.itn = itn
@@ -350,7 +352,8 @@ class Recognizer():
         svc_logger.info(f"Sample Rate: {sample_rate}, ITN: {self.itn}, Punctuation: {self.punctuation}")
 
         # init websocket client
-        self.ws = self.RecognizerWebSocket(self.__ws_uri, [("sample_rate",sample_rate), ("itn",self.itn), ("punctuation",self.punctuation)], self)
+        self.sample_rate = sample_rate
+        self.ws = self.RecognizerWebSocket(self.__ws_uri, [("sample_rate",self.sample_rate), ("itn",self.itn), ("punctuation",self.punctuation)], self)
 
     def get_server_url_token(self) -> bool:
         """get stt server url and speech token by login token"""
@@ -402,7 +405,7 @@ class Recognizer():
         self.is_running = True
         if self.reconnecting:
             self.reconnecting = False
-            self.ws = self.RecognizerWebSocket(self.__ws_uri, self)
+            self.ws = self.RecognizerWebSocket(self.__ws_uri, [("sample_rate",self.sample_rate), ("itn",self.itn), ("punctuation",self.punctuation)], self)
            
         if self.ws:
             self.ws.connect()
@@ -478,6 +481,7 @@ class Recognizer():
             svc_logger.error(f"Exception in continuous_recognition_async: {e}")
 
     def send_thread(self):
+        global i
         """Send data to websocket"""
         error_flag = False
 
@@ -504,8 +508,8 @@ class Recognizer():
                         svc_logger.warning("The ws has been disconnected, trying to reconnect..")
                         self.reconnecting = True
                         self.start_continuous_recognition()
-
-                    self.ws.send(buf, binary=True)
+                    else:
+                        self.ws.send(buf, binary=True)
 
             except KeyboardInterrupt:
                 error_flag = True
